pub(crate) fn apply_logcheck_rules(log_entry: &LogEntry) -> Option<RuleCategory>Expand description
Apply logcheck rules to a log entry using the modern rule database
pub(crate) fn apply_logcheck_rules(log_entry: &LogEntry) -> Option<RuleCategory>Apply logcheck rules to a log entry using the modern rule database